@@ -12,7 +12,9 @@
 # language governing permissions and limitations under the License.
 import re
 from contextlib import contextmanager
-from nose.tools import assert_equal, assert_true, assert_raises
+
+import pytest
+
 from tests import unittest, mock, BaseSessionTest, ClientHTTPStubber
 
 from botocore import exceptions
@@ -283,22 +285,22 @@ def _assert_signing_name(stubber, expected_name):
     request = stubber.requests[0]
     auth_header = request.headers['Authorization'].decode('utf-8')
     actual_name = V4_AUTH_REGEX.match(auth_header).group('name')
-    assert_equal(expected_name, actual_name)
+    assert expected_name == actual_name
 
 
 def _assert_netloc(stubber, expected_netloc):
     request = stubber.requests[0]
     url_parts = urlsplit(request.url)
-    assert_equal(expected_netloc, url_parts.netloc)
+    assert expected_netloc == url_parts.netloc
 
 
 def _assert_header(stubber, key, value):
     request = stubber.requests[0]
-    assert_true(key in request.headers)
+    assert key in request.headers
     actual_value = request.headers[key]
     if isinstance(actual_value, bytes):
         actual_value = actual_value.decode('utf-8')
-    assert_equal(value, actual_value)
+    assert value == actual_value
 
 
 def _assert_headers(stubber, headers):
@@ -325,26 +327,18 @@ def _bootstrap_test_case_client(session, test_case):
     return _bootstrap_client(session, region, config=config)
 
 
-def test_accesspoint_arn_redirection():
+@pytest.mark.parametrize("test_case", ACCESSPOINT_ARN_TEST_CASES)
+def test_accesspoint_arn_redirection(test_case):
     session = _bootstrap_session()
-    for test_case in ACCESSPOINT_ARN_TEST_CASES:
-        client, stubber = _bootstrap_test_case_client(session, test_case)
-        yield _test_accesspoint_arn, test_case, client, stubber
-
-
-def _test_accesspoint_arn(test_case, client, stubber):
+    client, stubber = _bootstrap_test_case_client(session, test_case)
     with _assert_test_case(test_case, client, stubber):
         client.get_access_point_policy(Name=test_case['arn'])
 
 
-def test_bucket_arn_redirection():
+@pytest.mark.parametrize("test_case", BUCKET_ARN_TEST_CASES)
+def test_bucket_arn_redirection(test_case):
     session = _bootstrap_session()
-    for test_case in BUCKET_ARN_TEST_CASES:
-        client, stubber = _bootstrap_test_case_client(session, test_case)
-        yield _test_bucket_arn, test_case, client, stubber
-
-
-def _test_bucket_arn(test_case, client, stubber):
+    client, stubber = _bootstrap_test_case_client(session, test_case)
     with _assert_test_case(test_case, client, stubber):
         client.get_bucket(Bucket=test_case['arn'])
 
@@ -372,7 +366,7 @@ def _assert_test_case(test_case, client, stubber):
         ) % (exception_cls, type(exception_raised))
         assert isinstance(exception_raised, exception_cls), error_msg
     else:
-        assert_equal(len(stubber.requests), 1)
+        assert len(stubber.requests) == 1
         if 'signing_name' in assertions:
             _assert_signing_name(stubber, assertions['signing_name'])
         if 'headers' in assertions:
@@ -420,9 +414,10 @@ class TestS3ControlRedirection(unittest.TestCase):
     def test_outpost_redirection_custom_endpoint(self):
         self._bootstrap_client(endpoint_url='https://outpost.foo.com/')
         self.stubber.add_response()
-        with self.assertRaises(UnsupportedS3ControlConfigurationError):
-            with self.stubber:
-                self.client.create_bucket(Bucket='foo', OutpostId='op-123')
+        with self.stubber:
+            self.client.create_bucket(Bucket='foo', OutpostId='op-123')
+        _assert_netloc(self.stubber, 'outpost.foo.com')
+        _assert_header(self.stubber, 'x-amz-outpost-id', 'op-123')
 
     def test_normal_ap_request_has_correct_endpoint(self):
         self.stubber.add_response()
@@ -430,6 +425,13 @@ class TestS3ControlRedirection(unittest.TestCase):
             self.client.get_access_point_policy(Name='MyAp', AccountId='1234')
         _assert_netloc(self.stubber, '1234.s3-control.us-west-2.amazonaws.com')
 
+    def test_normal_ap_request_custom_endpoint(self):
+        self._bootstrap_client(endpoint_url='https://example.com/')
+        self.stubber.add_response()
+        with self.stubber:
+            self.client.get_access_point_policy(Name='MyAp', AccountId='1234')
+        _assert_netloc(self.stubber, '1234.example.com')
+
     def test_normal_bucket_request_has_correct_endpoint(self):
         self.stubber.add_response()
         with self.stubber:
