@@ -1,8 +1,8 @@
+import pytest
+
 from tests import mock
 from tests import unittest
 
-from nose.tools import assert_equal, assert_is_instance
-
 from botocore.retries import standard
 from botocore.retries import quota
 from botocore import model
@@ -150,43 +150,46 @@ SERVICE_DESCRIPTION_WITH_RETRIES = {
     },
 }
 
-
-def test_can_detect_retryable_transient_errors():
+@pytest.mark.parametrize('case', RETRYABLE_TRANSIENT_ERRORS)
+def test_can_detect_retryable_transient_errors(case):
     transient_checker = standard.TransientRetryableChecker()
-    for case in RETRYABLE_TRANSIENT_ERRORS:
-        yield (_verify_retryable, transient_checker, None) + case
+    _verify_retryable(transient_checker, None, *case)
 
 
-def test_can_detect_retryable_throttled_errors():
+@pytest.mark.parametrize('case', RETRYABLE_THROTTLED_RESPONSES)
+def test_can_detect_retryable_throttled_errors(case):
     throttled_checker = standard.ThrottledRetryableChecker()
-    for case in RETRYABLE_THROTTLED_RESPONSES:
-        yield (_verify_retryable, throttled_checker, None) + case
+    _verify_retryable(throttled_checker, None, *case)
 
 
-def test_can_detect_modeled_retryable_errors():
+@pytest.mark.parametrize('case', RETRYABLE_MODELED_ERRORS)
+def test_can_detect_modeled_retryable_errors(case):
     modeled_retry_checker = standard.ModeledRetryableChecker()
-    test_params = (_verify_retryable, modeled_retry_checker,
-                   get_operation_model_with_retries())
-    for case in RETRYABLE_MODELED_ERRORS:
-        test_case = test_params + case
-        yield test_case
+    _verify_retryable(
+        modeled_retry_checker, get_operation_model_with_retries(), *case
+    )
 
 
-def test_standard_retry_conditions():
-    # This is verifying that the high level object used for checking
-    # retry conditions still handles all the individual testcases.
+@pytest.mark.parametrize('case',
+    [
+        case for case in
+        RETRYABLE_TRANSIENT_ERRORS +
+        RETRYABLE_THROTTLED_RESPONSES +
+        RETRYABLE_MODELED_ERRORS
+        if case[2]
+    ]
+)
+def test_standard_retry_conditions(case):
+    """This is verifying that the high level object used for checking
+    retry conditions still handles all the individual testcases.
+
+    It's possible that cases that are retryable for an individual checker
+    aren't retryable for a different checker.  We need to filter out all
+    the False cases (if case[2]).
+    """
     standard_checker = standard.StandardRetryConditions()
     op_model = get_operation_model_with_retries()
-    all_cases = (
-        RETRYABLE_TRANSIENT_ERRORS + RETRYABLE_THROTTLED_RESPONSES +
-        RETRYABLE_MODELED_ERRORS)
-    # It's possible that cases that are retryable for an individual checker
-    # are retryable for a different checker.  We need to filter out all
-    # the False cases.
-    all_cases = [c for c in all_cases if c[2]]
-    test_params = (_verify_retryable, standard_checker, op_model)
-    for case in all_cases:
-        yield test_params + case
+    _verify_retryable(standard_checker, op_model, *case)
 
 
 def get_operation_model_with_retries():
@@ -213,7 +216,7 @@ def _verify_retryable(checker, operation_model,
         http_response=http_response,
         caught_exception=caught_exception,
     )
-    assert_equal(checker.is_retryable(context), is_retryable)
+    assert checker.is_retryable(context) == is_retryable
 
 
 def arbitrary_retry_context():
@@ -233,36 +236,38 @@ def test_can_honor_max_attempts():
     checker = standard.MaxAttemptsChecker(max_attempts=3)
     context = arbitrary_retry_context()
     context.attempt_number = 1
-    assert_equal(checker.is_retryable(context), True)
+    assert checker.is_retryable(context) is True
 
     context.attempt_number = 2
-    assert_equal(checker.is_retryable(context), True)
+    assert checker.is_retryable(context) is True
 
     context.attempt_number = 3
-    assert_equal(checker.is_retryable(context), False)
+    assert checker.is_retryable(context) is False
 
 
 def test_max_attempts_adds_metadata_key_when_reached():
     checker = standard.MaxAttemptsChecker(max_attempts=3)
     context = arbitrary_retry_context()
     context.attempt_number = 3
-    assert_equal(checker.is_retryable(context), False)
-    assert_equal(context.get_retry_metadata(), {'MaxAttemptsReached': True})
+    assert checker.is_retryable(context) is False
+    assert context.get_retry_metadata() == {'MaxAttemptsReached': True}
 
 
 def test_can_create_default_retry_handler():
     mock_client = mock.Mock()
     mock_client.meta.service_model.service_id = model.ServiceId('my-service')
-    assert_is_instance(standard.register_retry_handler(mock_client),
-                       standard.RetryHandler)
+    assert isinstance(
+        standard.register_retry_handler(mock_client),
+        standard.RetryHandler
+    )
     call_args_list = mock_client.meta.events.register.call_args_list
     # We should have registered the retry quota to after-calls
     first_call = call_args_list[0][0]
     second_call = call_args_list[1][0]
     # Not sure if there's a way to verify the class associated with the
     # bound method matches what we expect.
-    assert_equal(first_call[0], 'after-call.my-service')
-    assert_equal(second_call[0], 'needs-retry.my-service')
+    assert first_call[0] == 'after-call.my-service'
+    assert second_call[0] == 'needs-retry.my-service'
 
 
 class TestRetryHandler(unittest.TestCase):
